==> nnhl-0.1.2.tar.gz: nnhl-0.1.2/src/MesJpn.h <==
	{ NMesNull,
		"" },

	/* Main win label */

	{ NMesLabelArt,
		"" },
	{ NMesLabelThr,
		"å" },
	{ NMesLabelSite,
		"" },
	{ NMesLabelSitePrev,
		"" },
	{ NMesLabelSiteNext,
		"" },
	{ NMesLabelBar,
		"̾" },

	/* Config win label */

	{ NMesLabelName,
		"̾" },
	{ NMesLabelUrl,
		"URL" },
	{ NMesLabelDownload,
		"ɤ߹" },
	{ NMesLabelDelete,
		"" },
	{ NMesLabelUpdate,
		"Ͽ" },
	{ NMesLabelNew,
		"Ͽ" },

	/* Socket */

	{ NMesRecvSrvrError,
		"ФǡޤǤ" },
	{ NMesRecvSrvrSendError,
		"Ф׵᤬ޤǤ" },
	{ NMesRecvSrvrHeaderError,
		"ФإåޤǤ" },

	/* Thread */

	{ NMesThreadCreateError,
		"åɤڤޤǤ" },

	/* Down Load */

	{ NMesHeadLineDefault,
		"ԵǤ" },

	{ NMesDownLoadOpen,
		"Ф³Ƥޤ" },
	{ NMesDownLoadOpenError,
		"Ф³ޤǤ" },
	{ NMesDownLoadRecv,
		"ФɤƤޤ" },
	{ NMesDownLoadClose,
		"Ф³Ƥޤ" },
	{ NMesDownLoadCloseError,
		"Ф³ޤǤ" },
	{ NMesDownLoadPickUp,
		"ǡѴƤޤ" },
	{ NMesDownLoadPickUpError,
		"˥塼ĤޤǤ" },

	/* URL */

	{ NMesUrlExistNameError,
		"̾ϤǤͭޤ" },
	{ NMesUrlNotExistNameError,
		"̾ͭޤ" },

	/* URL list */

	{ NMesUrlListSaveError,
		"ե˽񤭽ФޤǤ" },

	/* URL name list */

	{ NMesUrlName_news2_2ch_net_news5plus_,
		"˥塼+" },
	{ NMesUrlName_sports2_2ch_net_iraq_,
		"饯" },
	{ NMesUrlName_news2_2ch_net_news5_,
		"" },
	{ NMesUrlName_society_2ch_net_kokusai_,
		"ݾ" },
	{ NMesUrlName_tmp2_2ch_net_bakanews_,
		"Х˥塼" },
	{ NMesUrlName_tmp2_2ch_net_asia_,
		"˥塼" },
	{ NMesUrlName_news2_2ch_net_news2_,
		"˥塼" },
	{ NMesUrlName_pc_2ch_net_pcnews_,
		"PC˥塼" },
	{ NMesUrlName_comic_2ch_net_comicnews_,
		"˥ᡦ̡" },
	{ NMesUrlName_music3_2ch_net_musicnews_,
		"ǽ" },
	{ NMesUrlName_news6_2ch_net_trafficinfo_,
		"̾" },
	{ NMesUrlName_news4_2ch_net_news_,
		"˥塼®" },
	{ NMesUrlName_news5_2ch_net_newsplus_,
		"˥塼®+" },
	{ NMesUrlName_bbq_2ch_net_bbynews_,
		"®headline" },
	{ NMesUrlName_news7_2ch_net_femnewsplus_,
		"femalenews+" },
	{ NMesUrlName_news6_2ch_net_mnewsplus_,
		"ݥ®+" },
	{ NMesUrlName_book_2ch_net_bizplus_,
		"ӥͥnews+" },
	{ NMesUrlName_news8_2ch_net_eqplus_,
		"׻Ͽ+" },
	{ NMesUrlName_news8_2ch_net_eq_,
		"׻Ͽ" },

	/* Copyright */

	{ NMesAboutGame,
		"ܥץϥե꡼եȥǤ\n"
		"ʤϡ Free Software Foundation ɽ"
		" GNU ̸ͭѵΡ֥С󣲡"
		"ϤʹߤγƥС椫餤줫򤷡"
		"ΥС˽äܥץ"
		"ۤޤѹ뤳ȤǤޤ\n"
		"\n"
		"ܥץͭѤȤϻפޤۤˤäƤϡ"
		"ԾڤŪŬˤĤƤΰۤݾڤޤ,"
		"ʤݾڤԤʤޤ\n"
		"ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ\n"
		"\n"
		"ʤϡܥץȰ GNU ̸ͭѵ"
		"μ̤äƤϤǤǤʤϡ\n"
		"  Free Software Foundation, Inc.,\n"
		"  59 Temple Place, Suite 330, Boston, MA 02111-1307, USA\n"
		"ؼ񤤤Ƥ\n"
	},

==> nnhl-0.1.3.tar.gz: nnhl-0.1.3/src/MesJpn.h <==

#define STR_ARTICLE	""
#define STR_THREAD	"å"
#define STR_SITE	""

	{ NMesNull,
		"" },

	/* Main win label */

	{ NMesLabelArt,
		STR_ARTICLE },
	{ NMesLabelThr,
		STR_THREAD },
	{ NMesLabelSite,
		STR_SITE },
	{ NMesLabelSitePrev,
		"" },
	{ NMesLabelSiteNext,
		"" },
	{ NMesLabelBar,
		"̾" },

	/* Config win label */

	{ NMesLabelName,
		"̾" },
	{ NMesLabelUrl,
		"URL" },
	{ NMesLabelDownload,
		"ɤ߹" },
	{ NMesLabelEncoding,
		"ʸ" },
	{ NMesLabelSkipArt,
		STR_THREAD "" STR_ARTICLE "" },

	{ NMesLabelDelete,
		"" },
	{ NMesLabelUpdate,
		"Ͽ" },
	{ NMesLabelNew,
		"Ͽ" },

	{ NMesLabelOrder,
		"" },
	{ NMesLabelUp,
		"" },
	{ NMesLabelDown,
		"" },
	{ NMesLabelTop,
		"Ƭ" },
	{ NMesLabelBottom,
		"" },

	/* Socket */

	{ NMesRecvSrvrError,
		"ФǡޤǤ" },
	{ NMesRecvSrvrSendError,
		"Ф׵᤬ޤǤ" },
	{ NMesRecvSrvrHeaderError,
		"ФإåޤǤ" },

	/* Thread */

	{ NMesThreadCreateError,
		"åɤڤޤǤ" },

	/* Down Load */

	{ NMesHeadLineDefault,
		"ԵǤ" },

	{ NMesDownLoadOpen,
		"Ф³Ƥޤ" },
	{ NMesDownLoadOpenError,
		"Ф³ޤǤ" },
	{ NMesDownLoadRecv,
		"ФɤƤޤ" },
	{ NMesDownLoadClose,
		"Ф³Ƥޤ" },
	{ NMesDownLoadCloseError,
		"Ф³ޤǤ" },
	{ NMesDownLoadPickUp,
		"ǡѴƤޤ" },
	{ NMesDownLoadPickUpError,
		"˥塼ĤޤǤ" },

	/* URL */

	{ NMesUrlExistNameError,
		"̾ϤǤͭޤ" },
	{ NMesUrlNotExistNameError,
		"̾ͭޤ" },

	/* Config file */

	{ NMesSaveError,
		"ե˽񤭽ФޤǤ" },
	{ NMesLoadVerError,
		"ե뤬бƤʤСǤ" },

	/* URL name list */

	{ NMesUrlName_news2_2ch_net_news5plus_,
		"˥塼+" },
	{ NMesUrlName_sports2_2ch_net_iraq_,
		"饯" },
	{ NMesUrlName_news2_2ch_net_news5_,
		"" },
	{ NMesUrlName_society_2ch_net_kokusai_,
		"ݾ" },
	{ NMesUrlName_tmp2_2ch_net_bakanews_,
		"Х˥塼" },
	{ NMesUrlName_tmp2_2ch_net_asia_,
		"˥塼" },
	{ NMesUrlName_news2_2ch_net_news2_,
		"˥塼" },
	{ NMesUrlName_pc_2ch_net_pcnews_,
		"PC˥塼" },
	{ NMesUrlName_comic_2ch_net_comicnews_,
		"˥ᡦ̡" },
	{ NMesUrlName_music3_2ch_net_musicnews_,
		"ǽ" },
	{ NMesUrlName_news6_2ch_net_trafficinfo_,
		"̾" },
	{ NMesUrlName_news4_2ch_net_news_,
		"˥塼®" },
	{ NMesUrlName_news5_2ch_net_newsplus_,
		"˥塼®+" },
	{ NMesUrlName_bbq_2ch_net_bbynews_,
		"®headline" },
	{ NMesUrlName_news7_2ch_net_femnewsplus_,
		"femalenews+" },
	{ NMesUrlName_news6_2ch_net_mnewsplus_,
		"ݥ®+" },
	{ NMesUrlName_book_2ch_net_bizplus_,
		"ӥͥnews+" },
	{ NMesUrlName_news8_2ch_net_eqplus_,
		"׻Ͽ+" },
	{ NMesUrlName_news8_2ch_net_eq_,
		"׻Ͽ" },

	/* Copyright */

	{ NMesAboutGame,
		"ܥץϥե꡼եȥǤ\n"
		"ʤϡ Free Software Foundation ɽ"
		" GNU ̸ͭѵΡ֥С󣲡"
		"ϤʹߤγƥС椫餤줫򤷡"
		"ΥС˽äܥץ"
		"ۤޤѹ뤳ȤǤޤ\n"
		"\n"
		"ܥץͭѤȤϻפޤۤˤäƤϡ"
		"ԾڤŪŬˤĤƤΰۤݾڤޤ,"
		"ʤݾڤԤʤޤ\n"
		"ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ\n"
		"\n"
		"ʤϡܥץȰ GNU ̸ͭѵ"
		"μ̤äƤϤǤǤʤϡ\n"
		"  Free Software Foundation, Inc.,\n"
		"  59 Temple Place, Suite 330, Boston, MA 02111-1307, USA\n"
		"ؼ񤤤Ƥ\n"
	},

#undef STR_ARTICLE
#undef STR_THREAD
#undef STR_SITE
